@@ -520,8 +520,7 @@ Delay job for this many seconds (from now), defaults to C<0>.
 
   expire => 300
 
-Job is valid for this many seconds (from now) before it expires. Note that this option is B<EXPERIMENTAL> and might
-change without warning!
+Job is valid for this many seconds (from now) before it expires.
 
 =item lax
 
@@ -579,6 +578,6 @@ Stop job performed with L</"start"> immediately. Note that this method should on
 
 =head1 SEE ALSO
 
-L<Minion>, L<https://minion.pm>, L<Mojolicious::Guides>, L<https://mojolicious.org>.
+L<Minion>, L<Minion::Guide>, L<https://minion.pm>, L<Mojolicious::Guides>, L<https://mojolicious.org>.
 
 =cut
